==> 1.11.0.zip: vernissage/Vernissage/Views/StatusView/Subviews/StatusPlaceholderView.swift <==
//
//  https://mczachurski.dev
//  Copyright © 2023 Marcin Czachurski and the repository contributors.
//  Licensed under the Apache License 2.0.
//

import SwiftUI
import WidgetsKit

struct StatusPlaceholderView: View {
    @State var imageWidth: Double
    @State var imageHeight: Double
    @State var imageBlurhash: String?

    var body: some View {
        ScrollView {
            VStack(alignment: .leading) {
                if let imageBlurhash, let uiImage = UIImage(blurHash: imageBlurhash, size: CGSize(width: 32, height: 32)) {
                    Image(uiImage: uiImage)
                        .resizable()
                        .frame(width: self.imageWidth, height: self.imageHeight)
                } else {
                    Rectangle()
                        .fill(Color.placeholderText)
                        .frame(width: self.imageWidth, height: self.imageHeight)
                        .redacted(reason: .placeholder)
                }

                VStack(alignment: .leading) {
                    UsernameRow(accountId: "",
                                accountDisplayName: "Verylong Displayname",
                                accountUsername: "@username")

                    Text("Lorem ispum text something")
                        .foregroundColor(.customGrayColor)
                        .font(.footnote)
                    Text("Lorem ispum text something sdf sdfsdf sdfdsfsdfsdf")
                        .foregroundColor(.customGrayColor)
                        .font(.footnote)

                    LabelIcon(iconName: "mappin.and.ellipse", value: "Wroclaw, Poland")
                    LabelIcon(iconName: "camera", value: "SONY ILCE-7M3")
                    LabelIcon(iconName: "camera.aperture", value: "Viltrox 24mm F1.8 E")
                    LabelIcon(iconName: "timelapse", value: "24.0 mm, f/1.8, 1/640s, ISO 100")
                    LabelIcon(iconName: "calendar", value: "2 Oct 2022")
                }
                .padding(8)
                .redacted(reason: .placeholder)
                .animatePlaceholder(isLoading: .constant(true))
            }
        }
    }
}

==> 2.0.0.zip: vernissage/Vernissage/Views/StatusView/Subviews/StatusPlaceholderView.swift <==
//
//  https://mczachurski.dev
//  Copyright © 2023 Marcin Czachurski and the repository contributors.
//  Licensed under the Apache License 2.0.
//

import SwiftUI
import WidgetsKit

struct StatusPlaceholderView: View {
    @State var imageWidth: Double
    @State var imageHeight: Double
    @State var imageBlurhash: String?

    var body: some View {
        ScrollView {
            VStack(alignment: .leading) {
                if let imageBlurhash, let uiImage = UIImage(blurHash: imageBlurhash, size: CGSize(width: 32, height: 32)) {
                    Image(uiImage: uiImage)
                        .resizable()
                        .frame(width: self.imageWidth, height: self.imageHeight)
                } else {
                    Rectangle()
                        .fill(Color.placeholderText)
                        .frame(width: self.imageWidth, height: self.imageHeight)
                        .redacted(reason: .placeholder)
                }

                VStack(alignment: .leading) {
                    UsernameRow(accountId: "",
                                accountDisplayName: "Verylong Displayname",
                                accountUsername: "@username")

                    Text("statusPlaceholder.title.line1", comment: "Lorem ispum text something")
                        .foregroundColor(.customGrayColor)
                        .font(.footnote)
                    Text("statusPlaceholder.title.line2", comment: "Lorem ispum text something sdf sdfsdf sdfdsfsdfsdf")
                        .foregroundColor(.customGrayColor)
                        .font(.footnote)

                    LabelIcon(iconName: "mappin.and.ellipse", value: "Wroclaw, Poland")
                    LabelIcon(iconName: "camera", value: "SONY ILCE-7M3")
                    LabelIcon(iconName: "camera.aperture", value: "Viltrox 24mm F1.8 E")
                    LabelIcon(iconName: "timelapse", value: "24.0 mm, f/1.8, 1/640s, ISO 100")
                    LabelIcon(iconName: "calendar", value: "2 Oct 2022")
                }
                .padding(8)
                .redacted(reason: .placeholder)
                .animatePlaceholder(isLoading: .constant(true))
            }
        }
    }
}
